How Oscar Isaac and Jessica Chastain went about bringing to life 'A Most Violent Year' | Fox News Latino
Author: Lucia I. Suarez
Description: Isaac, who is of Cuban-Guatemalan heritage, plays a New York business owner who battles his morals in J.C. Chandor's A Most Violent Year alongside his longtime friend, Chastain.
Keywords: relationship,New York City,America,Star Wars,the time,American,Latin America,Jessica Chastain,Golden Globe,Colombia,Oscar Isaac,U S
Date: 2014-12-29

# How Oscar Isaac and Jessica Chastain went about bringing to life 'A Most Violent Year'

By Lucia I. Suarez

Published December 29, 2014
Fox News Latino

- In this image released by A24 Films, Jessica Chastain, left, and Oscar Isaac appear in a scene from "A Most Violent Year." Chastain was nominated for a Golden Globe for best supporting actress in a drama for her role in the film on Thursday, Dec. 11, 2014. The 72nd annual Golden Globe awards will air on NBC on Sunday, Jan. 11. (AP Photo/A24 Films, Atsushi Nishijima)AP2014

Oscar Isaac has had a pretty stellar year. It started off with a Golden Globe nomination for his portrayal of the title role in “Inside Llewyn Davis.”

He just completed filming in the next highly-anticipated installment of the “Star Wars” franchise, and he finishes off the year with a masterful performance in J.C. Chandor’s “A Most Violent Year, ”out on Dec. 31 in limited release.

Set in New York City in 1981, the 35-year-old Cuban-Guatemalan actor plays Abel Morales, a moral businessman in a very immoral time. He doesn't want to be a gangster and has to fight against himself, as well as everything around him, to make sure it never happens.

It was this tension that attracted Isaac to the role, which allowed him to work alongside longtime friend, Jessica Chastain, who co-stars as his wife, Anna.

“He doesn't want to be a gangster, and he has never wanted to be one. And he is afraid that if he starts down that path, that he will be dismissed as one – and also, possibly, that if he starts down that path, he will really like it,” Isaac told Fox News Latino recently during an interview that also included Chastain. “The tension that J.C. creates, it plays with the audience’s expectations. The audience gets a little bloodthirsty.”

For this internal battle fighting against violence, Chandor asked his leading man to pick a time in Latin America that the character had lived through and escaped.

“Scripts are vague on back-story, what you see on screen is what the actors get when they first (read it),” the director said. “Oscar’s character, I always believed, came to the U.S. sometime between 7 years old and 10 or 12 – in that window, so young enough that you are able to strip away your past and young enough that you really can become just an American in your adult life.”

He said Isaac zeroed in on a period of civil unrest in Colombia after World War II that is known as “La Violencia” ("The Violence").

“I thought it was a cool opportunity to tie in what his character was then going to be facing, the equivalent that he would have come here in the late 1950s probably and seen this city and America climb, climb, climb through the '60s and then in the late '60s and into the '70s, see the city of New York fall into this life of crime and people leaving the city – falling back into decay.”

Isaac said he chose that specific time because it would have been “really intense if (Abel) had left this incredibly violent situation to come to this country to escape the violence, and yet the violence follows him.”

To further develop their characters' back-stories, Isaac and Chastian, 37, used their mutual Julliard School training to discuss every scene.

“It’s pretty intense because the script itself is already quite dense, full of so many details, but also very mysterious 'cause there is not a lot of description of his past or even their past, how they got to where they are,” Isaac said. “We got together and went through every scene, every line and just talked about it. We started talking about possibilities of where this whole relationship started, when it started, how we met, when we decided to buy the business. Just to create the context so that when we started shooting, we had that bedrock.”

Chastain said that the director "really left (the script) free for us to explore … because he doesn’t want to taint our natural instincts."

Chandor attributed the two actors’ long off-screen friendship for making Abel and Anna’s onscreen relationship feel so real.

“I’m not sure if I knew it at the time, but, looking back at it now, it was just amazing cause there’s this shared history. The fact that they had known each other almost as long as the characters had – it was just meant to be,” he said.

“A Most Violent Year” hits select theaters on Dec. 31, followed by a wider release in January.

Next year Isaac will also appear in two blockbuster films, though “Star Wars: Episode VII” could probably the most secretive.

All known of Isaac’s character is that at the very least he pilots an X-wing fighter in the trailer.

Although he said it was “wild” to see himself in the film’s teaser, Isaac stopped short of revealing anything about it.

“I’ve signed away my organs,” he joked, adding that filming the iconic franchise was great. “J.J. Abrams is amazing.”

Like us on Facebook
Follow us on Twitter & Instagram

Follow Lucia I. Suarez on Twitter @luciasuarezsang

- Print
- Email
- Share
- Comments
- Recommend
- Tweet

## Related Slideshow

Miss Nevada Nia Sanchez Crowned As 63rd Miss USA

Check Out Hilaria Baldwin's Daily Photos Of Her Wacky And Racy Yoga Poses

Best pix of the week

Latino celebs dress up for Halloween

Latinos Undercover: Celebs You Never Guessed Had Hispanic Blood, Sí Señor!

## Share This Article

- View Article

You must login to comment.

View Article

## Follow Fox News Latino

#### Get Our Free Newsletter

Newsletter Signup

Advertisement

## More Stories

- ### NYC Mayor de Blasio met by boos, jeers during NYPD graduation ceremony

- ### GPS used to track some migrants caught crossing U.S.-Mexico border illegally

- ### Boyfriend of missing teen found wandering Arizona interstate

- ### White middle school teacher in the Bronx files discrimination suit against NYC

- ### Move over Kim Kardashian, Indianara Carvalho crowned Miss BumBum 2014

- ### Blood on the sand: Female matador, four others gored by enormous bull in Mexico City

- ### Antonio Banderas on his new girlfriend: 'We are in the process of getting to know each other'

- ### Forget fireworks, Mexico's Popocatépetl volcano puts on an explosive New Year's show

Advertisement

## Also on the web

- Avión de AirAsia no tenía permiso para volar el día de su desaparición
- Barack Obama y Enrique Peña Nieto se reunirán en la Casa Blanca para tratar relaciones bilaterales
- Policía en Atlanta es investigado por disparar "accidentalmente" contra su esposa
- Cuba está lista para celebrar los 56 años de la revolución en la Isla
- Casos de autoridades involucradas en crímenes está acabando con la confianza de los ciudadanos mexicanos

- Sofia Vergara -- Engaged to Joe Manganiello ... But Don't Tell Her Finger! (PHOTO)
- Salma Hayek -- Mama Mia ... That's Some Body! (PHOTO)
- Jennifer Lopez -- Drunk Driver Nailed ... That's How the D.A. Rolls
- Christina Aguilera -- Disneyland Tantrum ... Calls Mickey an A**hole
- Jose Canseco -- Gunshot Finger Making Incredible Recovery ... Says Ex

- 31 Hilarious Kids Who Know Exactly What They Want In Life
- 11 Babies That Hilariously Look Just Like Celebrities
- 23 People Who Will Make You Feel Brilliant
- 27 Cats That Look Like Something Else
- 21 Animals With Unique and Adorable Markings

- Iniesta no comprende ataques a Messi
- Gasol dice que D'Antoni está 'estropeando' su temporada
- Inglaterra derrota a Brasil
- Con 23 triples los Rockets aplastaron a los Warriors
- Sexygalería: Gisele Bundchen, consiente mucho a Tom Brady

- Chiquis Rivera shares heartbreaking message about mom Jenni Rivera
- 10 Latino celeb New Years bashes that made us jealous!
- 10 Fashion myths Latinas need to stop believing
- Ashton Kutcher and Mila Kunis may be married!
- Kim Kardashian addresses ALL the rumors in New Year's Twitter rant

- EXCLUSIVE: Pitbull Talks Performing for NYE & Bringing "Flavor" to 2015
- Zoe Saldaña Reveals the Names of Her Twins!
- How Your Favorite Celebs Celebrated the New Year!
- EXCLUSIVE: WWE's Rosa Mendes Talks 'Total Divas' & Her Costa Rican Roots
- Sofia Vergara's Best Selfies, Ever!